package org.apache.bcel.generic;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.apache.bcel.classfile.AccessFlags;
import org.apache.bcel.classfile.Attribute;

public abstract class FieldGenOrMethodGen extends AccessFlags implements NamedAndTyped, Cloneable {
   /** @deprecated */
   @Deprecated
   protected String name;
   /** @deprecated */
   @Deprecated
   protected Type type;
   /** @deprecated */
   @Deprecated
   protected ConstantPoolGen cp;
   private final List<Attribute> attributeList = new ArrayList();
   private final List<AnnotationEntryGen> annotationList = new ArrayList();

   protected FieldGenOrMethodGen() {
   }

   protected FieldGenOrMethodGen(int accessFlags) {
      super(accessFlags);
   }

   protected void addAll(Attribute[] attrs) {
      Collections.addAll(this.attributeList, attrs);
   }

   public void addAnnotationEntry(AnnotationEntryGen ag) {
      this.annotationList.add(ag);
   }

   public void addAttribute(Attribute a) {
      this.attributeList.add(a);
   }

   public Object clone() {
      try {
         return super.clone();
      } catch (CloneNotSupportedException var2) {
         throw new Error("Clone Not Supported");
      }
   }

   public AnnotationEntryGen[] getAnnotationEntries() {
      return (AnnotationEntryGen[])this.annotationList.toArray(AnnotationEntryGen.EMPTY_ARRAY);
   }

   public Attribute[] getAttributes() {
      return (Attribute[])this.attributeList.toArray(Attribute.EMPTY_ARRAY);
   }

   public ConstantPoolGen getConstantPool() {
      return this.cp;
   }

   public String getName() {
      return this.name;
   }

   public abstract String getSignature();

   public Type getType() {
      return this.type;
   }

   public void removeAnnotationEntries() {
      this.annotationList.clear();
   }

   public void removeAnnotationEntry(AnnotationEntryGen ag) {
      this.annotationList.remove(ag);
   }

   public void removeAttribute(Attribute a) {
      this.attributeList.remove(a);
   }

   public void removeAttributes() {
      this.attributeList.clear();
   }

   public void setConstantPool(ConstantPoolGen cp) {
      this.cp = cp;
   }

   public void setName(String name) {
      this.name = name;
   }

   public void setType(Type type) {
      if (type.getType() == 16) {
         throw new IllegalArgumentException("Type can not be " + type);
      } else {
         this.type = type;
      }
   }
}
